package cn.iocoder.yudao.module.jx.mapper;


import cn.iocoder.yudao.module.jx.domain.DriveSchoolReimbursement;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 报销审核Mapper接口
 *
 * @author ruoyi
 * @date 2024-05-19
 */
@Mapper
public interface DriveSchoolReimbursementMapper
{
    /**
     * 查询报销审核
     *
     * @param id 报销审核主键
     * @return 报销审核
     */
    public DriveSchoolReimbursement selectDriveSchoolReimbursementById(Long id);

    /**
     * 查询报销审核列表
     *
     * @param driveSchoolReimbursement 报销审核
     * @return 报销审核集合
     */
    public IPage<DriveSchoolReimbursement> selectDriveSchoolReimbursementList(@Param("entity") DriveSchoolReimbursement driveSchoolReimbursement, Page<DriveSchoolReimbursement> page);

    /**
     * 新增报销审核
     *
     * @param driveSchoolReimbursement 报销审核
     * @return 结果
     */
    public int insertDriveSchoolReimbursement(DriveSchoolReimbursement driveSchoolReimbursement);

    /**
     * 修改报销审核
     *
     * @param driveSchoolReimbursement 报销审核
     * @return 结果
     */
    public int updateDriveSchoolReimbursement(DriveSchoolReimbursement driveSchoolReimbursement);

    /**
     * 删除报销审核
     *
     * @param id 报销审核主键
     * @return 结果
     */
    public int deleteDriveSchoolReimbursementById(Long id);

    /**
     * 批量删除报销审核
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDriveSchoolReimbursementByIds(Long[] ids);
}
